<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->
**Table of Contents**  *generated with [DocToc](https://github.com/thlorenz/doctoc)*

- [WebHuman Automation Tool](#webhuman-automation-tool)
  - [Getting Started](#getting-started)
    - [Prerequisites](#prerequisites)
    - [Installation](#installation)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

# WebHuman Automation Tool

WebHuman is a Python-based automation tool that uses Playwright to interact with web pages.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Prerequisites

Before you begin, ensure you have the following installed:
- [Python 3.11](https://www.python.org/downloads/)
- [Poetry](https://python-poetry.org/docs/#installation)

### Installation

1. **Clone the repository**

   ```sh
   git clone https://your-repository-url.git
   cd webhuman
   ```
2. **Install dependencies**

   ```sh
    poetry install
    ```

3. *Define the following environment variables*

   ```sh
   export
   ```

4. **Run the project**

   ```sh
   python web_eye.py <url>
   ```
